@@ -153,13 +153,11 @@ IdentityGroup = [
                help="The public endpoint type to use for OpenStack Identity "
                     "(Keystone) API v2"),
     cfg.StrOpt('v3_endpoint_type',
-               default='adminURL',
+               default='public',
                choices=['public', 'admin', 'internal',
                         'publicURL', 'adminURL', 'internalURL'],
                help="The endpoint type to use for OpenStack Identity "
-                    "(Keystone) API v3. The default value adminURL is "
-                    "deprecated and will be modified to publicURL in "
-                    "the next release."),
+                    "(Keystone) API v3."),
     cfg.StrOpt('admin_role',
                default='admin',
                help="Role required to administrate keystone."),
@@ -201,8 +199,15 @@ IdentityGroup = [
                     "default value is 0 meaning disabling this feature. "
                     "NOTE: This config option value must be same as "
                     "keystone.conf: security_compliance.unique_last_password_"
-                    "count otherwise test might fail"
-               ),
+                    "count otherwise test might fail"),
+    cfg.IntOpt('user_minimum_password_age',
+               default=0,
+               help="The number of days that a password must be used before "
+                    "the user can change it. This only takes effect when "
+                    "identity-feature-enabled.security_compliance is set to "
+                    "'True'. For more details, refer to keystone config "
+                    "options "
+                    "keystone.conf:security_compliance.minimum_password_age.")
 ]
 
 service_clients_group = cfg.OptGroup(name='service-clients',
@@ -714,14 +719,6 @@ ImageFeaturesGroup = [
                                   'are current one. In future, Tempest will '
                                   'test v2 APIs only so this config option '
                                   'will be removed.'),
-    cfg.BoolOpt('api_v1',
-                default=False,
-                help="Is the v1 image API enabled",
-                deprecated_for_removal=True,
-                deprecated_reason='Glance v1 APIs are deprecated and v2 APIs '
-                                  'are current one. In future, Tempest will '
-                                  'test v2 APIs only so this config option '
-                                  'will be removed.'),
     # Image import feature is setup in devstack victoria onwards.
     # Once all stable branches setup the same via glance standalone
     # mode or with uwsgi, we can remove this config option.
@@ -1109,7 +1106,13 @@ VolumeFeaturesGroup = [
                      'server instance? This depends on the 3.42 volume API '
                      'microversion and the 2.51 compute API microversion. '
                      'Also, not all volume or compute backends support this '
+                     'operation.'),
+    cfg.BoolOpt('extend_volume_with_snapshot',
+                default=True,
+                help='Does the cloud support extending the size of a volume '
+                     'which has snapshot? Some drivers do not support this '
                      'operation.')
+
 ]
 
 
